@@ -6,7 +6,9 @@
 #define HOURLYMODEL_H
 
 #include <QAbstractListModel>
+
 #include <KWeatherCore/WeatherForecast>
+
 class HourlyModel : public QAbstractListModel
 {
     Q_OBJECT
@@ -14,7 +16,7 @@ class HourlyModel : public QAbstractListModel
     Q_PROPERTY(QString currentTemperature READ currentTemperature NOTIFY reseted)
     Q_PROPERTY(QString currentDescription READ currentDescription NOTIFY reseted)
 public:
-    enum HourlyRole {Time = Qt::UserRole + 1, Icon, Description, Temperature, Precipitation};
+    enum HourlyRole { Time = Qt::UserRole + 1, Icon, Description, Temperature, Precipitation };
     virtual QVariant data(const QModelIndex &index, int role) const override;
     virtual int rowCount(const QModelIndex &index) const override;
     virtual QHash<int, QByteArray> roleNames() const override;
@@ -23,12 +25,13 @@ public:
     const QString &currentDescription() const;
     Q_INVOKABLE void openKWeather();
 public Q_SLOTS:
-    void loadForecast(QExplicitlySharedDataPointer<KWeatherCore::WeatherForecast>);
+    void loadForecast(KWeatherCore::WeatherForecast);
 Q_SIGNALS:
     void reseted();
+
 private:
     const KWeatherCore::HourlyWeatherForecast &getNthHour(int index) const;
-    QExplicitlySharedDataPointer<KWeatherCore::WeatherForecast> m_location;
+    KWeatherCore::WeatherForecast m_location;
 };
 
 #endif // HOURLYNMODEL_H
