@@ -8,9 +8,10 @@
 
 #include <Plasma/Applet>
 
-#include <KWeatherCore/WeatherForecast>
+#include <KWeatherCore/WeatherForecastSource>
 
 class HourlyModel;
+class QTimer;
 class KWeather_1x4 : public Plasma::Applet
 {
     Q_OBJECT
@@ -56,8 +57,10 @@ private:
     QString m_location;
     double m_latitude, m_longitude;
     KWeatherCore::WeatherForecast m_forecast;
+    KWeatherCore::WeatherForecastSource m_source;
 
     HourlyModel *m_hourlyModel;
+    QTimer *m_timer;
 };
 
 #endif
